| Title: | Total Survey Error |
|---|---|
| Description: | Calculates total survey error (TSE) for one or more surveys, using common scale-dependent and/or scale-independent metrics. On TSE, see: Weisberg, Herbert (2005, ISBN:0-226-89128-3); Biemer, Paul (2010) <doi:10.1093/poq/nfq058>. |
| Authors: | Joshua Miller [aut, cre] |
| Maintainer: | Joshua Miller <[email protected]> |
| License: | GPL (>= 2) |
| Version: | 0.1.0 |
| Built: | 2026-05-17 06:39:13 UTC |
| Source: | https://github.com/cran/TSE |
Calculates average mean absolute error (aMAE) for one or more surveys
AVEMAE(Actuals1 = data.frame(), Observed1 = data.frame(), ...)AVEMAE(Actuals1 = data.frame(), Observed1 = data.frame(), ...)
Actuals1 |
= data from a "gold standard" survey; objects are variable columns from "gold standard" survey that corruspond to variable columns Observed1 |
Observed1 |
= data from survey 1; objects are variable columns from survey 1 that corruspond to variable columns from Actuals1 |
... |
= "gold standard" data/survey # data for additional surveys |
aMAE for survey # => mean value of the MAEs for specified variables in survey # => mean value of MAEs for objects in Observed#=data.frame()
Average mean absolute error (aMAE)
Make sure to properly order inputs, per the example: Actuals1=data.frame() objects and corrusponding Observed1=data.frame() objects must be given in the same order as each other; and ... must be given in numbered pairs of Actuals#, Observed#, and those pairs given in sequence of their #s.
AVEMAE(Actuals1=data.frame(TESTNUMB$AQ1, TESTNUMB$AQ2), Observed1=data.frame(TESTNUMB$O1Q1, TESTNUMB$O1Q2), Actuals2=data.frame(TESTNUMB$AQ1, TESTNUMB$AQ2), Observed2=data.frame(TESTNUMB$O2Q1, TESTNUMB$O2Q2), Actuals3=data.frame(TESTNUMB$AQ1, TESTNUMB$AQ2), Observed3=data.frame(TESTNUMB$O3Q1, TESTNUMB$O3Q2))AVEMAE(Actuals1=data.frame(TESTNUMB$AQ1, TESTNUMB$AQ2), Observed1=data.frame(TESTNUMB$O1Q1, TESTNUMB$O1Q2), Actuals2=data.frame(TESTNUMB$AQ1, TESTNUMB$AQ2), Observed2=data.frame(TESTNUMB$O2Q1, TESTNUMB$O2Q2), Actuals3=data.frame(TESTNUMB$AQ1, TESTNUMB$AQ2), Observed3=data.frame(TESTNUMB$O3Q1, TESTNUMB$O3Q2))
Calculates average mean absolute percentage error (aMAPE) for one or more surveys
AVEMAPE(Actuals1 = data.frame(), Observed1 = data.frame(), ...)AVEMAPE(Actuals1 = data.frame(), Observed1 = data.frame(), ...)
Actuals1 |
= data from a "gold standard" survey; objects are variable columns from "gold standard" survey that corruspond to variable columns Observed1 |
Observed1 |
= data from survey 1; objects are variable columns from survey 1 that corruspond to variable columns from Actuals1 |
... |
= "gold standard" data/survey # data for additional surveys |
aMAPE for survey # => mean value of the MAPEs for specified variables in survey # => mean value of MAPEs for objects in Observed#=data.frame()
Average mean absolute percentage error (aMAPE)
Make sure to properly order inputs, per the example: Actuals1=data.frame() objects and corrusponding Observed1=data.frame() objects must be given in the same order as each other; and ... must be given in numbered pairs of Actuals#, Observed#, and those pairs given in sequence of their #s.
AVEMAPE(Actuals1=data.frame(TESTNUMB$AQ1, TESTNUMB$AQ2), Observed1=data.frame(TESTNUMB$O1Q1, TESTNUMB$O1Q2), Actuals2=data.frame(TESTNUMB$AQ1, TESTNUMB$AQ2), Observed2=data.frame(TESTNUMB$O2Q1, TESTNUMB$O2Q2), Actuals3=data.frame(TESTNUMB$AQ1, TESTNUMB$AQ2), Observed3=data.frame(TESTNUMB$O3Q1, TESTNUMB$O3Q2))AVEMAPE(Actuals1=data.frame(TESTNUMB$AQ1, TESTNUMB$AQ2), Observed1=data.frame(TESTNUMB$O1Q1, TESTNUMB$O1Q2), Actuals2=data.frame(TESTNUMB$AQ1, TESTNUMB$AQ2), Observed2=data.frame(TESTNUMB$O2Q1, TESTNUMB$O2Q2), Actuals3=data.frame(TESTNUMB$AQ1, TESTNUMB$AQ2), Observed3=data.frame(TESTNUMB$O3Q1, TESTNUMB$O3Q2))
Calculates average mean squared error (aMSE) with bias-variance decomposition for one or more surveys
AVEMSE(Actuals1 = data.frame(), Observed1 = data.frame(), ...)AVEMSE(Actuals1 = data.frame(), Observed1 = data.frame(), ...)
Actuals1 |
= data from a "gold standard" survey; objects are variable columns from "gold standard" survey that corruspond to variable columns Observed1 |
Observed1 |
= data from survey 1; objects are variable columns from survey 1 that corruspond to variable columns from Actuals1 |
... |
= "gold standard" data/survey # data for additional surveys |
aMSE for survey # => mean value of the MSEs for specified variables in survey # => mean value of MSEs for objects in Observed#=data.frame()
Average mean squared error (aMSE) with bias-variance decomposition
Make sure to properly order inputs, per the example: Actuals1=data.frame() objects and corrusponding Observed1=data.frame() objects must be given in the same order as each other; and ... must be given in numbered pairs of Actuals#, Observed#, and those pairs given in sequence of their #s.
AVEMSE(Actuals1=data.frame(TESTNUMB$AQ1, TESTNUMB$AQ2), Observed1=data.frame(TESTNUMB$O1Q1, TESTNUMB$O1Q2), Actuals2=data.frame(TESTNUMB$AQ1, TESTNUMB$AQ2), Observed2=data.frame(TESTNUMB$O2Q1, TESTNUMB$O2Q2), Actuals3=data.frame(TESTNUMB$AQ1, TESTNUMB$AQ2), Observed3=data.frame(TESTNUMB$O3Q1, TESTNUMB$O3Q2))AVEMSE(Actuals1=data.frame(TESTNUMB$AQ1, TESTNUMB$AQ2), Observed1=data.frame(TESTNUMB$O1Q1, TESTNUMB$O1Q2), Actuals2=data.frame(TESTNUMB$AQ1, TESTNUMB$AQ2), Observed2=data.frame(TESTNUMB$O2Q1, TESTNUMB$O2Q2), Actuals3=data.frame(TESTNUMB$AQ1, TESTNUMB$AQ2), Observed3=data.frame(TESTNUMB$O3Q1, TESTNUMB$O3Q2))
Calculates average mean squared logarithmic error (aMSLE) for one or more surveys
AVEMSLE(Actuals1 = data.frame(), Observed1 = data.frame(), ...)AVEMSLE(Actuals1 = data.frame(), Observed1 = data.frame(), ...)
Actuals1 |
= data from a "gold standard" survey; objects are variable columns from "gold standard" survey that corruspond to variable columns Observed1 |
Observed1 |
= data from survey 1; objects are variable columns from survey 1 that corruspond to variable columns from Actuals1 |
... |
= "gold standard" data/survey # data for additional surveys |
aMSLE for survey # => mean value of the MSLEs for specified variables in survey # => mean value of MSLEs for objects in Observed#=data.frame()
Average mean squared logarithmic error (aMSLE)
Make sure to properly order inputs, per the example: Actuals1=data.frame() objects and corrusponding Observed1=data.frame() objects must be given in the same order as each other; and ... must be given in numbered pairs of Actuals#, Observed#, and those pairs given in sequence of their #s.
AVEMSLE(Actuals1=data.frame(TESTNUMB$AQ1, TESTNUMB$AQ2), Observed1=data.frame(TESTNUMB$O1Q1, TESTNUMB$O1Q2), Actuals2=data.frame(TESTNUMB$AQ1, TESTNUMB$AQ2), Observed2=data.frame(TESTNUMB$O2Q1, TESTNUMB$O2Q2), Actuals3=data.frame(TESTNUMB$AQ1, TESTNUMB$AQ2), Observed3=data.frame(TESTNUMB$O3Q1, TESTNUMB$O3Q2))AVEMSLE(Actuals1=data.frame(TESTNUMB$AQ1, TESTNUMB$AQ2), Observed1=data.frame(TESTNUMB$O1Q1, TESTNUMB$O1Q2), Actuals2=data.frame(TESTNUMB$AQ1, TESTNUMB$AQ2), Observed2=data.frame(TESTNUMB$O2Q1, TESTNUMB$O2Q2), Actuals3=data.frame(TESTNUMB$AQ1, TESTNUMB$AQ2), Observed3=data.frame(TESTNUMB$O3Q1, TESTNUMB$O3Q2))
Calculates average relative absolute error (aRAE) for one or more surveys
AVERAE(Actuals1 = data.frame(), Observed1 = data.frame(), ...)AVERAE(Actuals1 = data.frame(), Observed1 = data.frame(), ...)
Actuals1 |
= data from a "gold standard" survey; objects are variable columns from "gold standard" survey that corruspond to variable columns Observed1 |
Observed1 |
= data from survey 1; objects are variable columns from survey 1 that corruspond to variable columns from Actuals1 |
... |
= "gold standard" data/survey # data for additional surveys |
aRAE for survey # => mean value of the RAEs for specified variables in survey # => mean value of RAEs for objects in Observed#=data.frame()
Average relative absolute error (aRAE)
Make sure to properly order inputs, per the example: Actuals1=data.frame() objects and corrusponding Observed1=data.frame() objects must be given in the same order as each other; and ... must be given in numbered pairs of Actuals#, Observed#, and those pairs given in sequence of their #s.
AVERAE(Actuals1=data.frame(TESTNUMB$AQ1, TESTNUMB$AQ2), Observed1=data.frame(TESTNUMB$O1Q1, TESTNUMB$O1Q2), Actuals2=data.frame(TESTNUMB$AQ1, TESTNUMB$AQ2), Observed2=data.frame(TESTNUMB$O2Q1, TESTNUMB$O2Q2), Actuals3=data.frame(TESTNUMB$AQ1, TESTNUMB$AQ2), Observed3=data.frame(TESTNUMB$O3Q1, TESTNUMB$O3Q2))AVERAE(Actuals1=data.frame(TESTNUMB$AQ1, TESTNUMB$AQ2), Observed1=data.frame(TESTNUMB$O1Q1, TESTNUMB$O1Q2), Actuals2=data.frame(TESTNUMB$AQ1, TESTNUMB$AQ2), Observed2=data.frame(TESTNUMB$O2Q1, TESTNUMB$O2Q2), Actuals3=data.frame(TESTNUMB$AQ1, TESTNUMB$AQ2), Observed3=data.frame(TESTNUMB$O3Q1, TESTNUMB$O3Q2))
Calculates average root mean squared error (aRMSE) for one or more surveys
AVERMSE(Actuals1 = data.frame(), Observed1 = data.frame(), ...)AVERMSE(Actuals1 = data.frame(), Observed1 = data.frame(), ...)
Actuals1 |
= data from a "gold standard" survey; objects are variable columns from "gold standard" survey that corruspond to variable columns Observed1 |
Observed1 |
= data from survey 1; objects are variable columns from survey 1 that corruspond to variable columns from Actuals1 |
... |
= "gold standard" data/survey # data for additional surveys |
aRMSE for survey # => mean value of the RMSEs for specified variables in survey # => mean value of RMSEs for objects in Observed#=data.frame()
Average root mean squared error (aRMSE)
Make sure to properly order inputs, per the example: Actuals1=data.frame() objects and corrusponding Observed1=data.frame() objects must be given in the same order as each other; and ... must be given in numbered pairs of Actuals#, Observed#, and those pairs given in sequence of their #s.
AVERMSE(Actuals1=data.frame(TESTNUMB$AQ1, TESTNUMB$AQ2), Observed1=data.frame(TESTNUMB$O1Q1, TESTNUMB$O1Q2), Actuals2=data.frame(TESTNUMB$AQ1, TESTNUMB$AQ2), Observed2=data.frame(TESTNUMB$O2Q1, TESTNUMB$O2Q2), Actuals3=data.frame(TESTNUMB$AQ1, TESTNUMB$AQ2), Observed3=data.frame(TESTNUMB$O3Q1, TESTNUMB$O3Q2))AVERMSE(Actuals1=data.frame(TESTNUMB$AQ1, TESTNUMB$AQ2), Observed1=data.frame(TESTNUMB$O1Q1, TESTNUMB$O1Q2), Actuals2=data.frame(TESTNUMB$AQ1, TESTNUMB$AQ2), Observed2=data.frame(TESTNUMB$O2Q1, TESTNUMB$O2Q2), Actuals3=data.frame(TESTNUMB$AQ1, TESTNUMB$AQ2), Observed3=data.frame(TESTNUMB$O3Q1, TESTNUMB$O3Q2))
Calculates average root mean squared logarithmic error (aRMSLE) for one or more surveys
AVERMSLE(Actuals1 = data.frame(), Observed1 = data.frame(), ...)AVERMSLE(Actuals1 = data.frame(), Observed1 = data.frame(), ...)
Actuals1 |
= data from a "gold standard" survey; objects are variable columns from "gold standard" survey that corruspond to variable columns Observed1 |
Observed1 |
= data from survey 1; objects are variable columns from survey 1 that corruspond to variable columns from Actuals1 |
... |
= "gold standard" data/survey # data for additional surveys |
aRMSLE for survey # => mean value of the RMSLEs for specified variables in survey # => mean value of RMSLEs for objects in Observed#=data.frame()
Average root mean squared logarithmic error (aRMSLE)
Make sure to properly order inputs, per the example: Actuals1=data.frame() objects and corrusponding Observed1=data.frame() objects must be given in the same order as each other; and ... must be given in numbered pairs of Actuals#, Observed#, and those pairs given in sequence of their #s.
AVERMSLE(Actuals1=data.frame(TESTNUMB$AQ1, TESTNUMB$AQ2), Observed1=data.frame(TESTNUMB$O1Q1, TESTNUMB$O1Q2), Actuals2=data.frame(TESTNUMB$AQ1, TESTNUMB$AQ2), Observed2=data.frame(TESTNUMB$O2Q1, TESTNUMB$O2Q2), Actuals3=data.frame(TESTNUMB$AQ1, TESTNUMB$AQ2), Observed3=data.frame(TESTNUMB$O3Q1, TESTNUMB$O3Q2))AVERMSLE(Actuals1=data.frame(TESTNUMB$AQ1, TESTNUMB$AQ2), Observed1=data.frame(TESTNUMB$O1Q1, TESTNUMB$O1Q2), Actuals2=data.frame(TESTNUMB$AQ1, TESTNUMB$AQ2), Observed2=data.frame(TESTNUMB$O2Q1, TESTNUMB$O2Q2), Actuals3=data.frame(TESTNUMB$AQ1, TESTNUMB$AQ2), Observed3=data.frame(TESTNUMB$O3Q1, TESTNUMB$O3Q2))
Calculates average root relative squared error (aRRSE) for one or more surveys
AVERRSE(Actuals1 = data.frame(), Observed1 = data.frame(), ...)AVERRSE(Actuals1 = data.frame(), Observed1 = data.frame(), ...)
Actuals1 |
= data from a "gold standard" survey; objects are variable columns from "gold standard" survey that corruspond to variable columns Observed1 |
Observed1 |
= data from survey 1; objects are variable columns from survey 1 that corruspond to variable columns from Actuals1 |
... |
= "gold standard" data/survey # data for additional surveys |
aRRSE for survey # => mean value of the RRSEs for specified variables in survey # => mean value of RRSEs for objects in Observed#=data.frame()
Average root relative squared error (aRRSE)
Make sure to properly order inputs, per the example: Actuals1=data.frame() objects and corrusponding Observed1=data.frame() objects must be given in the same order as each other; and ... must be given in numbered pairs of Actuals#, Observed#, and those pairs given in sequence of their #s.
AVERRSE(Actuals1=data.frame(TESTNUMB$AQ1, TESTNUMB$AQ2), Observed1=data.frame(TESTNUMB$O1Q1, TESTNUMB$O1Q2), Actuals2=data.frame(TESTNUMB$AQ1, TESTNUMB$AQ2), Observed2=data.frame(TESTNUMB$O2Q1, TESTNUMB$O2Q2), Actuals3=data.frame(TESTNUMB$AQ1, TESTNUMB$AQ2), Observed3=data.frame(TESTNUMB$O3Q1, TESTNUMB$O3Q2))AVERRSE(Actuals1=data.frame(TESTNUMB$AQ1, TESTNUMB$AQ2), Observed1=data.frame(TESTNUMB$O1Q1, TESTNUMB$O1Q2), Actuals2=data.frame(TESTNUMB$AQ1, TESTNUMB$AQ2), Observed2=data.frame(TESTNUMB$O2Q1, TESTNUMB$O2Q2), Actuals3=data.frame(TESTNUMB$AQ1, TESTNUMB$AQ2), Observed3=data.frame(TESTNUMB$O3Q1, TESTNUMB$O3Q2))
Calculates average relative squared error (aRSE) for one or more surveys
AVERSE(Actuals1 = data.frame(), Observed1 = data.frame(), ...)AVERSE(Actuals1 = data.frame(), Observed1 = data.frame(), ...)
Actuals1 |
= data from a "gold standard" survey; objects are variable columns from "gold standard" survey that corruspond to variable columns Observed1 |
Observed1 |
= data from survey 1; objects are variable columns from survey 1 that corruspond to variable columns from Actuals1 |
... |
= "gold standard" data/survey # data for additional surveys |
aRSE for survey # => mean value of the RSEs for specified variables in survey # => mean value of RSEs for objects in Observed#=data.frame()
Average relative squared error (aRSE)
Make sure to properly order inputs, per the example: Actuals1=data.frame() objects and corrusponding Observed1=data.frame() objects must be given in the same order as each other; and ... must be given in numbered pairs of Actuals#, Observed#, and those pairs given in sequence of their #s.
AVERSE(Actuals1=data.frame(TESTNUMB$AQ1, TESTNUMB$AQ2), Observed1=data.frame(TESTNUMB$O1Q1, TESTNUMB$O1Q2), Actuals2=data.frame(TESTNUMB$AQ1, TESTNUMB$AQ2), Observed2=data.frame(TESTNUMB$O2Q1, TESTNUMB$O2Q2), Actuals3=data.frame(TESTNUMB$AQ1, TESTNUMB$AQ2), Observed3=data.frame(TESTNUMB$O3Q1, TESTNUMB$O3Q2))AVERSE(Actuals1=data.frame(TESTNUMB$AQ1, TESTNUMB$AQ2), Observed1=data.frame(TESTNUMB$O1Q1, TESTNUMB$O1Q2), Actuals2=data.frame(TESTNUMB$AQ1, TESTNUMB$AQ2), Observed2=data.frame(TESTNUMB$O2Q1, TESTNUMB$O2Q2), Actuals3=data.frame(TESTNUMB$AQ1, TESTNUMB$AQ2), Observed3=data.frame(TESTNUMB$O3Q1, TESTNUMB$O3Q2))
Calculates average symmetric mean absolute percentage error (aSMAPE) for one or more surveys
AVESMAPE(Actuals1 = data.frame(), Observed1 = data.frame(), ...)AVESMAPE(Actuals1 = data.frame(), Observed1 = data.frame(), ...)
Actuals1 |
= data from a "gold standard" survey; objects are variable columns from "gold standard" survey that corruspond to variable columns Observed1 |
Observed1 |
= data from survey 1; objects are variable columns from survey 1 that corruspond to variable columns from Actuals1 |
... |
= "gold standard" data/survey # data for additional surveys |
aSMAPE for survey # => mean value of the SMAPEs for specified variables in survey # => mean value of SMAPEs for objects in Observed#=data.frame()
Average symmetric mean absolute percentage error (aSMAPE)
Make sure to properly order inputs, per the example: Actuals1=data.frame() objects and corrusponding Observed1=data.frame() objects must be given in the same order as each other; and ... must be given in numbered pairs of Actuals#, Observed#, and those pairs given in sequence of their #s.
AVESMAPE(Actuals1=data.frame(TESTNUMB$AQ1, TESTNUMB$AQ2), Observed1=data.frame(TESTNUMB$O1Q1, TESTNUMB$O1Q2), Actuals2=data.frame(TESTNUMB$AQ1, TESTNUMB$AQ2), Observed2=data.frame(TESTNUMB$O2Q1, TESTNUMB$O2Q2), Actuals3=data.frame(TESTNUMB$AQ1, TESTNUMB$AQ2), Observed3=data.frame(TESTNUMB$O3Q1, TESTNUMB$O3Q2))AVESMAPE(Actuals1=data.frame(TESTNUMB$AQ1, TESTNUMB$AQ2), Observed1=data.frame(TESTNUMB$O1Q1, TESTNUMB$O1Q2), Actuals2=data.frame(TESTNUMB$AQ1, TESTNUMB$AQ2), Observed2=data.frame(TESTNUMB$O2Q1, TESTNUMB$O2Q2), Actuals3=data.frame(TESTNUMB$AQ1, TESTNUMB$AQ2), Observed3=data.frame(TESTNUMB$O3Q1, TESTNUMB$O3Q2))
Calculates full scale-dependent statistics for one or more surveys
FULLSD(Actuals1 = data.frame(), Observed1 = data.frame(), ...)FULLSD(Actuals1 = data.frame(), Observed1 = data.frame(), ...)
Actuals1 |
= data from a "gold standard" survey; objects are variable columns from "gold standard" survey that corruspond to variable columns Observed1 |
Observed1 |
= data from survey 1; objects are variable columns from survey 1 that corruspond to variable columns from Actuals1 |
... |
= "gold standard" data/survey # data for additional surveys |
Full scale-dependent statistics
Make sure to properly order inputs, per the example: Actuals1=data.frame() objects and corrusponding Observed1=data.frame() objects must be given in the same order as each other; and ... must be given in numbered pairs of Actuals#, Observed#, and those pairs given in sequence of their #s.
FULLSD(Actuals1=data.frame(TESTNUMB$AQ1, TESTNUMB$AQ2), Observed1=data.frame(TESTNUMB$O1Q1, TESTNUMB$O1Q2), Actuals2=data.frame(TESTNUMB$AQ1, TESTNUMB$AQ2), Observed2=data.frame(TESTNUMB$O2Q1, TESTNUMB$O2Q2), Actuals3=data.frame(TESTNUMB$AQ1, TESTNUMB$AQ2), Observed3=data.frame(TESTNUMB$O3Q1, TESTNUMB$O3Q2))FULLSD(Actuals1=data.frame(TESTNUMB$AQ1, TESTNUMB$AQ2), Observed1=data.frame(TESTNUMB$O1Q1, TESTNUMB$O1Q2), Actuals2=data.frame(TESTNUMB$AQ1, TESTNUMB$AQ2), Observed2=data.frame(TESTNUMB$O2Q1, TESTNUMB$O2Q2), Actuals3=data.frame(TESTNUMB$AQ1, TESTNUMB$AQ2), Observed3=data.frame(TESTNUMB$O3Q1, TESTNUMB$O3Q2))
Calculates full scale-independent statistics for one or more surveys
FULLSI(Actuals1 = data.frame(), Observed1 = data.frame(), ...)FULLSI(Actuals1 = data.frame(), Observed1 = data.frame(), ...)
Actuals1 |
= data from a "gold standard" survey; objects are variable columns from "gold standard" survey that corruspond to variable columns Observed1 |
Observed1 |
= data from survey 1; objects are variable columns from survey 1 that corruspond to variable columns from Actuals1 |
... |
= "gold standard" data/survey # data for additional surveys |
Full scale-independent statistics
Make sure to properly order inputs, per the example: Actuals1=data.frame() objects and corrusponding Observed1=data.frame() objects must be given in the same order as each other; and ... must be given in numbered pairs of Actuals#, Observed#, and those pairs given in sequence of their #s.
FULLSI(Actuals1=data.frame(TESTNUMB$AQ1, TESTNUMB$AQ2), Observed1=data.frame(TESTNUMB$O1Q1, TESTNUMB$O1Q2), Actuals2=data.frame(TESTNUMB$AQ1, TESTNUMB$AQ2), Observed2=data.frame(TESTNUMB$O2Q1, TESTNUMB$O2Q2), Actuals3=data.frame(TESTNUMB$AQ1, TESTNUMB$AQ2), Observed3=data.frame(TESTNUMB$O3Q1, TESTNUMB$O3Q2))FULLSI(Actuals1=data.frame(TESTNUMB$AQ1, TESTNUMB$AQ2), Observed1=data.frame(TESTNUMB$O1Q1, TESTNUMB$O1Q2), Actuals2=data.frame(TESTNUMB$AQ1, TESTNUMB$AQ2), Observed2=data.frame(TESTNUMB$O2Q1, TESTNUMB$O2Q2), Actuals3=data.frame(TESTNUMB$AQ1, TESTNUMB$AQ2), Observed3=data.frame(TESTNUMB$O3Q1, TESTNUMB$O3Q2))
A data set created by merging four smaller data sets. Three of those smaller data sets are data from three surveys (O1, O2, O3); the other is data from a "gold standard" survey (A1). All four smaller data sets consist of the same three variables (Q1, Q2, Q3): responses to the same three questions, asked by each survey from the same 10 respondents (ID), along the same 1-99 response scale.
TESTNUMBTESTNUMB
A data frame with 10 rows and 13 variables
sets of three variables from each of four surveys, merged together
Example data generated by author